# modelTissueFlow

This is a program for analyzing time series movies for computing tissue velocity (PIV) and other signals (myosin)

Application: https://www.pnas.org/doi/10.1073/pnas.2214205120

## Note

Testing and contributing is very welcome, especially if you can contribute with new algorithms and features.

## Installing

Use PyPI (<https://pypi.org/project/modelTissueFlow/>):

    pip install modelTissueFlow

## To build from source

Option 1: Download the package from the Github:https://github.com/HiBandan/modelTissueFlow/archive/refs/heads/main.zip

    python setup.py install 
    
Option 2: Clone from terminal: 

    git clone https://github.com/HiBandan/modelTissueFlow.git

    python setup.py install 

## Testing the package

An example of use of this package can be found in the folder: example (https://github.com/HiBandan/modelTissueFlow)


